#!/bin/bash

# check if nlvm tool is available
nlvm="/sbin/nlvm"
echo $nlvm
if [ -f $nlvm ];
then
   echo "This is probably an OES server !"
   echo "Continue with mounting pools and volumes"
else
   echo "This is probably NOT an OES server !"
   echo "The required tool $nlvm does not exist"
   echo "Cancel mounting pools and volumes"
   exit
fi

# Set Sesam environment
source `/usr/bin/grep -i '^sm_ini=' /etc/sesam2000.ini|/usr/bin/cut -d"=" -f2` 2>/dev/null
source "${gv_rw_ini}/sesam2000.profile" >/dev/null 2>&1

# READ INI
read_ini()
{
  SM_INI=`/usr/bin/grep -i '^sm_ini=' /etc/sesam2000.ini|/usr/bin/cut -d '=' -f2`
  echo `/usr/bin/grep -i "$1=" "$SM_INI"|/usr/bin/cut -d"=" -f2`
}




# variables
count=1
p=p
hk="'"
dhk="\""
actdate=`date +%Y-%m-%d`
acttime=`date +%`
GV_RW_TMP=`read_ini gv_rw_tmp`
tpath="/usr/bin"
cpath="/bin"
npath="/sbin"


#preserve /etc/fstab because nlvm adds entries automatically
$cpath/cp /etc/fstab $GV_RW_TMP'fstab_org' 

# create file with entries for activated pools
$tpath/touch $GV_RW_TMP'act_pools'

# create file with entries for activated volumes
$tpath/touch $GV_RW_TMP'act_vols'

# rescan partitions ans pools
	$cpath/echo "*****************************************"
	$cpath/echo "Available NSS pools before rescan:"
	$npath/nlvm -m list pools
	$npath/nlvm -r -m
	$cpath/echo "*****************************************"
	$cpath/echo "Available NSS pools after rescan:"
	$npath/nlvm -m list pools

# number of available NSS pools
pcount1=$( $npath/nlvm -m list pools | $tpath/grep -v State | $tpath/wc -l )

###$cpath/echo "available NSS pools: "
###$npath/nlvm -m list pools

# set variable for check if no pools available 
nopools="$($npath/nlvm -m list pools)"

if [[ "$nopools" == *No?pools* ]] 
	then
	$cpath/echo "*****************************************"
	$cpath/echo 
	$cpath/echo " Non NSS pool available for restore !"
	$cpath/echo
	$cpath/echo "*****************************************"
	exit
	fi

# inc the number of pools for loops
let pcount2=($pcount1+1)



	# for each POOL do
	for (( count=1; count < $pcount2; count++))
	do
	# investigate the 5 values for each pool, format to: (Name State Size Shared IsSnap) and assign to an array pool1, pool2...
 	pval="$($npath/nlvm -m list pools | $tpath/grep -v State | $tpath/sed -n $count$p | $tpath/tr -s ' ' ' ' | $tpath/sed 's/^\s/("/g' | $tpath/sed 's/$/")/g' | $tpath/sed 's/\s/" "/g' | $tpath/sed 's/\$/\\\$/g' | $tpath/sed 's/\.//g')"
        
	case $count in
   		1)
     		declare -a pool1=$pval
     		;;
		2)
		declare -a pool2=$pval
     		;;
		3)
     		declare -a pool3=$pval
     		;;
		4)
     		declare -a pool4=$pval
     		;;
		5)
     		declare -a pool5=$pval
     		;;
		6)
     		declare -a pool6=$pval
     		;;
		7)
     		declare -a pool7=$pval
     		;;
		8)
     		declare -a pool8=$pval
     		;;
		9)
     		declare -a pool9=$pval
     		;;
		10)
     		declare -a pool10=$pval;
     		;;
   	esac	
	done

# activate all available pools if they are not a snap pool 
for (( count=1; count < $pcount2; count++))
	do
	pname=pool$count[0]
        pstate=pool$count[1]
	psnap=pool$count[4]
	$cpath/echo "*****************************************"
	$cpath/echo
	$cpath/echo "values of array$count 'PoolName' 'isActive' 'isSnap': "
	$cpath/echo "$pname = ${!pname} , $pstate = ${!pstate} , $psnap = ${!psnap} "
		if [[ ${!pstate} != "Active" && ${!psnap} == "No" ]] && [[ ${!pstate} != "NotMounted" ]]
			then
			$npath/nlvm -m -d pool activate ${!pname}
			$cpath/echo ${!pname} >>$GV_RW_TMP'act_pools'
			$cpath/echo "after activating NSS pool: ${!pname} "
			$npath/nlvm -m list pool ${!pname}
		fi 

		if [[ ${!pstate} == "NotMounted" && ${!psnap} == "No" ]]
			then
			$npath/nlvm -m -d mount ${!pname}
			$cpath/echo ${!pname} >>$GV_RW_TMP'act_pools'
			$cpath/echo "after mounting not mounted NSS pool: ${!pname} "
			$npath/nlvm -m list pool ${!pname}
		fi 
			

	done


# number of volumes
vcount1=$( $npath/nlvm list volumes | $tpath/grep -v Shared | $tpath/tr -s ' ' ' '| $tpath/sed 's/^\s//g' | $tpath/sed 's/\s$//g' | $tpath/wc -l )

# inc the number of volumes for loops
let vcount2=($vcount1+1)

# 
for (( count=1; count < $vcount2; count++))
	do
	# NSS volume name
	vname=$( $npath/nlvm list volumes | $tpath/grep -v Shared | $tpath/sed -n $count$p | $tpath/tr -s ' ' ' '| $tpath/sed 's/^\s//g' | $tpath/sed 's/\s$//g' | $tpath/cut -d " " -f 1)
	# add an underscore if the volume starts with a #
	vname2=$( $npath/nlvm list volumes | $tpath/grep -v Shared | $tpath/sed -n $count$p | $tpath/tr -s ' ' ' '| $tpath/sed 's/^\s//g' | $tpath/sed 's/\s$//g' | $tpath/sed 's/^#/_&/g' | $tpath/cut -d " " -f 1)
	# state of the volume
	vstate=$( $npath/nlvm list volumes | $tpath/grep -v Shared | $tpath/sed -n $count$p | $tpath/tr -s ' ' ' '| $tpath/sed 's/^\s//g' | $tpath/sed 's/\s$//g' | $tpath/cut -d " " -f 3)
	$cpath/echo "*****************************************"
	$cpath/echo	
	$cpath/echo "general status of volume $vname : $vstate "
	vmount=$( $npath/nlvm list volumes | $tpath/grep -v Shared | $tpath/sed -n $count$p | $tpath/tr -s ' ' ' '| $tpath/sed 's/^\s//g' | $tpath/sed 's/\s$//g' | $tpath/cut -d " " -f 4)
	$cpath/echo "*****************************************"
	$cpath/echo
	$cpath/echo "mount status of volume $vname : $vmount"
		# mount volume if Deactive or not mounted
		if [[ $vstate == "Deactive" ]] || [[ $vmount == "No" ]]
			then
				# create mountpoint if not exist
				if [ ! -d /mnt/$vname ]
				then 
				mkdir /mnt/$vname
				fi
			# mount NSS volume
			mount -t nssvol $vname2 /mnt/$vname/ -o name=$vname
				if [ $? -ne 0 ]
				then
				$cpath/echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
				$cpath/echo " Error mounting volume $vname "
				$cpath/echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
				else
                                echo $vname | sed 's/\$/\\\$/g' >>$GV_RW_TMP'act_vols'
                                fi
		
			fi
	done
$cpath/echo "*****************************************"
$cpath/echo 
$cpath/echo "available Volumes for restore under /mnt/<volume name>/ :"
$npath/nlvm -m list volumes
$cpath/echo 
$cpath/echo "*****************************************"
$cpath/echo 
$cpath/echo " END OF PRE SCRIPT FOR MOUNTING NSS VOLUMES "
$cpath/echo 
exit
